# History

## 0.1.3 – 2023-09-25

* Update ``keras`` adapter [Issue #7](https://github.com/sintel-dev/ml-stars/issues/7) - by @sarahmish

## 0.1.2 – 2023-08-04

* Add python 3.9 [Issue #6](https://github.com/sintel-dev/ml-stars/issues/6) - by @sarahmish


## 0.1.1 - 2023-05-17

* Fix ARIMA adapter [Issue #5](https://github.com/sintel-dev/ml-stars/issues/5) - by @sarahmish
* Add Documentation [Issue #4](https://github.com/sintel-dev/ml-stars/issues/4) - by @sarahmish


## 0.1.0 - 2023-04-18

First official ml-stars release to PyPI: https://pypi.org/project/ml-stars/
